@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-06-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,7 @@ _
             cmdline_aliases => {m=>{}},
         },
         module_srcs => {
-            summary => 'Module source codes',
+            summary => 'Module source codes (a hash, keys are module names)',
             schema  => ['hash*', {
                 each_key=>['str*', match=>$mod_re],
                 each_value=>['str*'],
@@ -279,12 +279,14 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.04 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-12.
+This document describes version 0.05 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-06-17.
 
 =head1 SEE ALSO
 
 L<App::FatPack>, L<App::fatten>
 
+L<fatpack-modules>, CLI for C<fatpack_modules>
+
 =head1 FUNCTIONS
 
 
@@ -312,7 +314,7 @@ Module names to search.
 
 =item * B<module_srcs> => I<hash>
 
-Module source codes.
+Module source codes (a hash, keys are module names).
 
 =item * B<output> => I<str>
 
